from gi.repository import Gtk

class TahrirToolbar(Gtk.Toolbar):

    def __init__(self):
        Gtk.Toolbar.__init__(self)
        self.get_style_context().add_class('primary-toolbar')

        self.newDoc = Gtk.ToolButton.new_from_stock('gtk-new')
        self.openDoc = Gtk.ToolButton.new_from_stock('gtk-open')
        self.saveDoc = Gtk.ToolButton.new_from_stock('gtk-save')
        separator = Gtk.SeparatorToolItem()
        self.searchDoc = Gtk.ToolButton.new_from_stock('gtk-find')
        self.goLeft = Gtk.ToolButton.new_from_stock('gtk-go-back')
        self.documentsBox = Gtk.ComboBoxText()
        self.goRight = Gtk.ToolButton.new_from_stock('gtk-go-forward')
        spacer = Gtk.ToolItem()
        spacer.set_expand(True)
        showSidebar = Gtk.ToolButton.new_from_stock('gtk-index')
        self.appSettings = Gtk.ToolButton.new_from_stock('gtk-properties')

        toolitem = Gtk.ToolItem()
        toolitem.add(self.documentsBox)
        self.insert(self.newDoc, -1)
        self.insert(self.openDoc, -1)
        self.insert(self.saveDoc, -1)
        self.insert(separator, -1)
        self.insert(self.goLeft, -1)
        self.insert(toolitem, -1)
        self.insert(self.goRight, -1)
        self.insert(spacer, -1)
        self.insert(self.searchDoc, -1)
        self.insert(showSidebar, -1)
        self.insert(self.appSettings, -1)

        self.show_all()
        self.saveDoc.hide()
        self.goLeft.hide()
        self.goRight.hide()
        self.newDoc.connect('clicked', self._onNewClicked)
        self.openDoc.connect('clicked', self._onOpenClicked)
        self.saveDoc.connect('clicked', self._onSaveClicked)
        self.documentsBox.connect('changed', self._onDocumentChanged)
        self.goLeft.connect('clicked', self._onGoLeft)
        self.goRight.connect('clicked', self._onGoRight)

    def showSaveIcon(self, boolean):
        self.saveDoc.set_visible(boolean)

    def controlArrows(self, showWhat):
        if showWhat == 'all':
            self.go_left.show()
            self.go_right.show()
        elif showWhat == 'left':
            self.go_left.show()
            self.go_right.hide()
        elif showWhat == 'right':
            self.go_right.show()
            self.go_left.hide()
        elif showWhat == 'none':
            self.go_right.hide()
            self.go_left.hide()

    def _onNewClicked(self, btn):
        parent = self.get_parent().get_parent()
        parent.newDocument()

    def _onOpenClicked(self, btn):
        parent = self.get_parent().get_parent()
        parent.openDialog()

    def _onSaveClicked(self, btn):
        parent = self.get_parent().get_parent()
        parent.saveRequest()

    def _onDocumentChanged(self, data):
        parent = self.get_parent().get_parent()
        active_id = int(data.get_active_id())
        docs = len(parent.documents)
        parent.switchView(active_id-1)
        if docs == 1:
            self.control_arrows('none')
        elif docs > 1:
            if active_id == 1:
                self.control_arrows('right')
            elif active_id > 0 and active_id < docs:
                self.control_arrows('all')
            elif active_id == docs:
                self.control_arrows('left')
        modified = parent.documents[active_id-1].get_modified()
        self.showSaveIcon(modified)

    def _onGoLeft(self, btn):
        activeId = self.documentsBox.get_active_id()
        newId = int(activeId)-1
        self.documentsBox.set_active_id(str(newId))

    def _onGoRight(self, btn):
        activeId = self.documentsBox.get_active_id()
        newId = int(activeId)+1
        self.documentsBox.set_active_id(str(newId))
